@@ -368,7 +368,8 @@ class DynamoFL(_Base):
             self.project_participants.append({
                 'project_key': i['projectKey'],
                 'datasource_key': i['datasourceKey'],
-                'trainer_key': i['trainerKey']
+                'trainer_key': i['trainerKey'],
+                'hyper_param_values': i['hyperParamValues']
             })
 
         ds = _Datasource(self, key)
